@@ -6,32 +6,8 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2012-2025 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2012-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
 """
 Convenience decorators for developers of UMC modules
@@ -447,7 +423,7 @@ def simple_response(function=None, with_flavor=None, with_progress=False, with_r
     # the name is not important as it is removed from the list while
     # being processed. Even a variable named 'iterator' in the original
     # function does not break anything
-    _fake_func._original_argument_names = ['self', 'iterator'] + _fake_func._original_argument_names[1:]
+    _fake_func._original_argument_names = ['self', 'iterator', *_fake_func._original_argument_names[1:]]
 
     _multi_response = _eval_simple_decorated_function(_fake_func, with_flavor, with_request=with_request)
 
