@@ -6,35 +6,12 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2020-2025 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2020-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
 import cgitb
 import json
+import re
 
 
 cgitb.enable()
@@ -57,13 +34,15 @@ def application(environ, start_response):
         service_name = 'Portal Server'
         if status == 503:
             reason = 'Portal Service Unavailable'
-    elif url.startswith('/univention/'):
+    elif re.match('^/univention/(auth|saml|oidc|get|set|command|upload|logout|logout-sse)($|/.*$)', url):
         service_name = 'Univention Management Console Server'
         service = 'univention-management-console-server'
         if status == 503:
             reason = 'UMC Service Unavailable'
+    elif url.startswith('/univention/'):
+        pass
 
-    message = "The %s could not be reached. Please restart %s or try again later." % (service_name, service)
+    message = "The %s could not be reached. Please try again later, try accesssing via https and FQDN or restart %s." % (service_name, service)
     if status == 502:
         message += ' %s' % (environ.get('REDIRECT_ERROR_NOTES', ''),)
         message = message.rstrip()
